#!/bin/bash /
set -e
backupRootPath=""
backupName=$1
if [ $2 == "default" ];then
	if [ $3 == "baksys" ]; then
		backupRootPath="/backup_data/"
		backupPath="/backup_data"
		root="/mnt/"
	else
		backupRootPath="/opt/backup-recover/backup_data/"
		backupPath="/opt/backup-recover/backup_data"
		root="/"
	fi
else
	backupPath=$2
	if [ $3 == "baksys" ]; then
		backupRootPath="/backup_data/"
		root="/mnt/"
	else
		backupRootPath="/opt/backup-recover/backup_data/"
		root="/"
	fi
fi
backupExcludeList=${backupRootPath}var/exclude.list
firstBackup=${backupRootPath}BACKUP_FIRST/
size=""


getCurBackupList()
{
	rsync -avh --delete-before  --exclude-from=$backupExcludeList --dry-run $root $firstBackup > ${backupRootPath}var/lib/${backupName}_include.list
	sed -i '/^\.\//d' ${backupRootPath}var/lib/${backupName}_include.list
	grep  'deleting ' ${backupRootPath}var/lib/${backupName}_include.list | awk '{print $2}' > ${backupRootPath}var/lib/${backupName}firstRecoverExciude.list
	sed -i '/^deleting .*\|^total size .*\|^sent .*\|^sending .*\|^created .*\|^building.*\|^$/d'  ${backupRootPath}var/lib/${backupName}_include.list
}

getDir()
{
	if [ $1 == "usrsys" ]; then
		find /bin /boot /var /etc /lib* /sbin /usr -type d -exec ls -ld {}/ \; | awk '{print $9}' > ${backupRootPath}/var/lib/rootDir.list
		sed -i 's/^.//' ${backupRootPath}/var/lib/rootDir.list
	else
		find /mnt/bin /mnt/boot /mnt/var /mnt/etc /mnt/lib* /mnt/sbin /mnt/usr -type d -exec ls -ld {}/ \; | awk '{print $9}' > ${backupRootPath}/var/lib/rootDir.list
		sed -i 's#^/mnt/##' ${backupRootPath}/var/lib/rootDir.list
	fi

	diff ${backupRootPath}/var/lib/rootDir.list ${backupRootPath}var/lib/${backupName}_include.list  | grep -v '>' | grep '<' | awk '{print $2}' >> ${backupRootPath}var/lib/${backupName}_include.list
}

getBackupSize()
{
	echo 2
	echo $1
	if [ $1 == "default" ]; then
		getCurBackupList
		rsync -avh --dry-run  --include-from=${backupRootPath}var/lib/${backupName}_include.list --exclude "*" --exclude "/*" "$root" ${backupPath}/${backupName}/ > ${backupRootPath}var/log/${backupName}_backup.log
	else
	echo 3
		rsync -avh --dry-run --exclude-from=$backupExcludeList "$root" ${backupPath}/${backupName}/ > ${backupRootPath}var/log/${backupName}_backup.log
	fi
	size=`tail -n 1 ${backupRootPath}var/log/${backupName}_backup.log | awk '{print $4}'`
	echo $size
}

toDoBackup()
{
	if [ $1 == "default" ]; then
		getDir $2
		rsync -avh --include-from=${backupRootPath}var/lib/${backupName}_include.list --exclude "*" --exclude "/*" "$root" ${backupPath}/${backupName}/ > ${backupRootPath}var/log/${backupName}_backup.log
	else
		rsync -avh  --exclude-from=$backupExcludeList "$root" ${backupPath}/${backupName}/ > ${backupRootPath}var/log/${backupName}_backup.log
	fi
}

toDoRecover()
{ 
	if [ $1 == "default" ]; then
		recoverCmd="rsync -avh --delete-before --exclude-from=${backupRootPath}var/lib/${backupName}firstRecoverExciude.list --exclude-from=$backupExcludeList ${firstBackup}/ $root > ${backupRootPath}var/log/${backupName}_recover.log"
		echo $recvoerCmd
		rsync -avh  --delete-before  --exclude-from=${backupRootPath}var/lib/${backupName}firstRecoverExciude.list --exclude-from=$backupExcludeList ${firstBackup}/ $root > ${backupRootPath}var/log/${backupName}_recover.log
		recoverCmd="rsync -avh ${backupPath}/${backupName}/ $root  >>${backupRootPath}var/log/${backupName}_recover.log"
		echo $recvoerCmd
		rsync -avh  ${backupPath}/${backupName}/ $root  >>${backupRootPath}var/log/${backupName}_recover.log
	else
		echo "start custom recover"
		
		recoverCmd="rsync -avh --delete-before --exclude-from=$backupExcludeList ${backupPath}/${backupName}/  $root > ${backupRootPath}var/log/${backupName}_recover.log"
		echo $recoverCmd
		rsync -avh --delete-before  --exclude-from=$backupExcludeList ${backupPath}/${backupName}/  $root > ${backupRootPath}var/log/${backupName}_recover.log
	fi
	bash /usr/bin/clearCache.sh recover
}

toDoReset()
{
	rsync -avh --delete-before --include "tmp/updatepool/" --exclude-from=$backupExcludeList ${firstBackup} $root > /backup_data/var/log/BACKUP_FIRST_recover.log
	resetCmd="rsync -avh --delete-before --exclude-from=$backupExcludeList ${firstBackup} $root > /backup_data/var/log/BACKUP_FIRST_recover.log"
	echo $resetCmd
	cd /mnt/tmp
	mount --bind /proc /mnt/proc
	mount --bind /sys /mnt/sys
	mount --bind /dev /mnt/dev
	mount --bind /run /mnt/run
	chroot $root bash /tmp/updatepool/installpatch
	bash /usr/bin/clearCache.sh recover
}

if [ $4 == "getsize" ]; then
	getBackupSize $2
	echo 1
fi

if [ $4 == "backup" ]; then
	toDoBackup $2 $3
fi

if [ $4 == "recover" ]; then
	toDoRecover $2 $3
fi

if [ $4 == "reset" ]; then
	toDoReset $2
fi
exit 0
